@@ -10,15 +10,14 @@ use Carp;
 use Scalar::Util qw(blessed);
 use SOAP::WSDL::Client;
 use SOAP::WSDL::Expat::WSDLParser;
-use Class::Std::Fast;
+use Class::Std::Fast constructor => 'none';
 use SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType;
 use LWP::UserAgent;
 
-our $VERSION= '2.00_33';
+use version; our $VERSION = qv('2.00.99_1');
 
 my %no_dispatch_of      :ATTR(:name<no_dispatch>);
 my %wsdl_of             :ATTR(:name<wsdl>);
-my %proxy_of            :ATTR(:name<proxy>);
 my %autotype_of         :ATTR(:name<autotype>);
 my %outputxml_of        :ATTR(:name<outputxml> :default<0>);
 my %outputtree_of       :ATTR(:name<outputtree>);
@@ -42,7 +41,6 @@ my %LOOKUP = (
   no_dispatch           => \%no_dispatch_of,
   class_resolver        => \%class_resolver_of,
   wsdl                  => \%wsdl_of,
-  proxy                 => \%proxy_of,
   autotype              => \%autotype_of,
   outputxml             => \%outputxml_of,
   outputtree            => \%outputtree_of,
@@ -94,12 +92,30 @@ for my $method (keys %LOOKUP ) {
         }
 
         my $ident = ident $self;
-        $self->wsdlinit() if ($wsdl_of{ $ident });
         $client_of{ $ident } = SOAP::WSDL::Client->new();
+        $self->wsdlinit() if ($wsdl_of{ $ident });
         return $self;
     }
 }
 
+sub set_proxy {
+    my $self = shift;
+    return $self->get_client()->set_proxy(@_);
+}
+
+sub get_proxy {
+    my $self = shift;
+    return $self->get_client()->get_proxy();
+}
+
+sub proxy {
+    my $self = shift;
+    if (@_) {
+        return $self->set_proxy(@_);
+    }
+    return $self->get_proxy();
+}
+
 sub wsdlinit {
     my ($self, %opt) = @_;
     my $ident = ident $self;
@@ -109,6 +125,7 @@ sub wsdlinit {
         ? (keep_alive => 1)
         : ()
     );
+    $lwp->agent(qq[SOAP::WSDL $VERSION]);
     my $response = $lwp->get( $wsdl_of{ $ident } );
     croak $response->message() if ($response->code != 200);
 
@@ -132,6 +149,15 @@ sub wsdlinit {
 
     $servicename_of{ $ident } = $opt{servicename} if $opt{servicename};
     $portname_of{ $ident } = $opt{portname} if $opt{portname};
+
+    $self->_wsdl_init_methods();
+
+    # pass-through keep_alive if we need it...
+    $self->get_client()->set_proxy(
+        $port_of{ $ident }->first_address()->get_location(),
+        $keep_alive_of{ $ident } ? (keep_alive => 1) : (),
+    );
+
     return $self;
 } ## end sub wsdlinit
 
@@ -151,6 +177,7 @@ sub _wsdl_get_port :PRIVATE  {
         ? $service_of{ $ident }->get_port( $ns, $portname_of{ $ident } )
         : $port_of{ $ident } = $service_of{ $ident }->get_port()->[ 0 ];
 }
+
 sub _wsdl_get_binding :PRIVATE {
     my $self = shift;
     my $ident = ident $self;
@@ -160,6 +187,7 @@ sub _wsdl_get_binding :PRIVATE {
         or croak "no binding found for ", $port->get_binding();
     return $binding_of{ $ident };
 }
+
 sub _wsdl_get_portType :PRIVATE {
     my $self    = shift;
     my $ident   = ident $self;
@@ -169,6 +197,7 @@ sub _wsdl_get_portType :PRIVATE {
         or croak "cannot find portType for " . $binding->get_type();
     return $porttype_of{ $ident };
 }
+
 sub _wsdl_init_methods :PRIVATE {
     my $self = shift;
     my $ident = ident $self;
@@ -240,6 +269,10 @@ sub _wsdl_init_methods :PRIVATE {
     return $method_info_of{ $ident };
 }
 
+# on_action is a no-op and just here for compatibility reasons.
+# It returns the first parameter to allow method chaining.
+sub on_action { return shift }
+
 sub call {
     my ($self, $method, @data_from) = @_;
     my $ident = ${ $self };
@@ -255,12 +288,6 @@ sub call {
 
     my $client = $client_of{ $ident };
 
-    # pass-through keep_alive if we need it...
-    $client->set_proxy( $proxy_of{ $ident }
-        || $port_of{ $ident }->first_address()->get_location(),
-        $keep_alive_of{ $ident } ? (keep_alive => 1) : (),
-    );
-
     $client->set_no_dispatch( $no_dispatch_of{ $ident } );
     $client->set_outputxml( $outputxml_of{ $ident } ? 1 : 0 );
 
@@ -273,7 +300,7 @@ sub call {
       && ( ! $no_dispatch_of{ $ident } ) ) {
         require SOAP::WSDL::Deserializer::SOM;
         $client->set_deserializer( SOAP::WSDL::Deserializer::SOM->new() );
-    };
+    }
 
     my $method_info = $method_info_of{ $ident }->{ $method };
 
@@ -512,7 +539,7 @@ it's content.
 The object tree has two main functions: It knows how to serialize data passed
 as hash ref, and how to render the WSDL elements found into perl classes.
 
-Yup your're right, there's a builting code generation facility. Read
+Yup you're right; there's a builtin code generation facility. Read
 L<SOAP::WSDL::Manual> for using it.
 
 =item * no_dispatch
@@ -555,6 +582,12 @@ SOAP message to your favorite XML editor and run the source format command.
 Outputting readable XML requires lots of programming for little use: The
 resulting XMl is still quite unreadable.
 
+=head2 on_action
+
+Setting on_action is not required any more, the appropriate value is
+automatically taken from the WSDL. on_action is a no-op, and is just here
+for compatibility issues.
+
 =head1 Differences to SOAP::Lite
 
 =head2 readable
@@ -595,7 +628,7 @@ See L<class_resolver|class_resolver> above.
 
 =item * Hash refs
 
-This is for convnience: A single hash ref containing the content of the
+This is for convenience: A single hash ref containing the content of the
 SOAP body.
 
 =item * xml
@@ -675,13 +708,13 @@ interpreting mod:
  simpleContent
 
 The following XML Schema definition content model is only partially
-supported:
+supported in interpreting mode:
 
  complexContent - only restriction variety supported
 
 See L<SOAP::WSDL::Manual::XSD> for details.
 
-=item * Serialization of hash refs dos not work for ambiguos values
+=item * Serialization of hash refs does not work for ambiguous values
 
 If you have list elements with multiple occurences allowed, SOAP::WSDL
 has no means of finding out which variant you meant.
@@ -691,17 +724,17 @@ Passing in item => [1,2,3] could serialize to
  <item>1 2</item><item>3</item>
  <item>1</item><item>2 3</item>
 
-Ambiguos data can be avoided by providing data as objects.
+Ambiguous data can be avoided by providing data as objects.
 
 =item * XML Schema facets
 
-Almost no XML schema facets are implemented yet. The only facets
+Almost no XML schema facets are implemented. The only facets
 currently implemented are:
 
  fixed
  default
 
-The following facets have no influence yet:
+The following facets have no influence:
 
  minLength
  maxLength
@@ -725,10 +758,10 @@ The following facets have no influence yet:
 Full featured SOAP-library, little WSDL support. Supports rpc-encoded style
 only. Many protocols supported.
 
-=item * L<XML::Compile::WSDL|XML::Compile::WSDL> / L<XML::Compile::SOAP|XML::Compile::SOAP>
+=item * L<XML::Compile::SOAP|XML::Compile::SOAP>
 
 Creates parser/generator functions for SOAP messages. Includes SOAP Client
-and Server implementatios.
+and Server implementations. Can validate XML messages.
 
 You might want to give it a try, especially if you need to adhere very
 closely to the XML Schema / WSDL specs.
@@ -762,23 +795,29 @@ Peter Orvos, Mark Overmeer, Jon Robens, Isidro Vila Verde and Glenn Wood
 (in alphabetical order) spotted bugs and/or suggested improvements in
 the 1.2x releases.
 
-Andreas 'ac0v' Specht constantly asked for better performance.
-
 JT Justman and Noah Robin provided early feedback and bug reports for
 the 2.xx pre-releases.
 
 Adam Kennedy checked and suggested improvements on metadata and dependencies
 in the 2.xx pre-releases.
 
-CPAN Testers have provided most valuable (automated) feedback. Thanks.
+Andreas 'ac0v' Specht constantly asked for better performance.
 
-Numerous people sent me their real-world WSDL files for testing. Thank you.
+Matt S. Trout encouraged me "to get a non-dev-release out."
+
+CPAN Testers provided most valuable (automated) feedback. Thanks a lot.
+
+Numerous people sent me their real-world WSDL files and error reports for
+testing. Thank you.
+
+Noah Robin contributed lots of documentation fixes, and the mod_perl server,
+and eventually joined SOAP::WSDL's developement. Thanks.
+
+Mark Overmeer wrote XML::Compile::SOAP - competition is good for business.
 
 Paul Kulchenko and Byrne Reese wrote and maintained SOAP::Lite and
 thus provided a base (and counterpart) for SOAP::WSDL.
 
-Mark Overmeer wrote XML::Compile::SOAP - competition is good for business.
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2004-2008 Martin Kutter.
@@ -792,9 +831,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 583 $
+ $Rev: 838 $
  $LastChangedBy: kutterma $
- $Id: WSDL.pm 583 2008-03-24 07:44:06Z kutterma $
- $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL.pm $
+ $Id: WSDL.pm 838 2009-03-09 20:10:23Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/branches/Typemap/lib/SOAP/WSDL.pm $
 
 =cut
