@@ -4,25 +4,25 @@ use warnings;
 use base 'SOAP::WSDL::Client';
 use Scalar::Util qw(blessed);
 
-our $VERSION = '2.00_25';
+use version; our $VERSION = qv('2.00.099_1');
 
 sub call {
     my ($self, $method, $body, $header) = @_;
 
     # Treat non-objects special
     if (not blessed $body) {
-        
+
         # make sure there's something sensible in our body data
         $body = {} if not defined $body;
         $body = ref $body eq 'ARRAY' ? $body : [ $body ];
 
         my @body_from = @{ $body }; # make a copy
 
-        # build list of parts as objects initialized with 
+        # build list of parts as objects initialized with
         # parameters given
         my @part_from = ();
         foreach my $class (@{ $method->{ body }->{ parts } }) {
-            eval "require $class" || die $@;
+            eval "require $class" || die $@;    ## no critic (ProhibitStringyEval)
             push @part_from, $class->new(shift(@body_from) || {});
         }
 
@@ -33,10 +33,10 @@ sub call {
     # if we have a header
     if (%{ $method->{ header } }) {
 
-        # trat non object special - as above, but only for one
+        # treat non object special - as above, but only for one
         if (not blessed $header) {
             my $class = $method->{ header }->{ parts }->[0];
-            eval "require $class" || die $@;
+            eval "require $class" || die $@;    ## no critic (ProhibitStringyEval)
             $header = $class->new($header);
         }
     }
@@ -65,6 +65,13 @@ SOAP::WSDL::Client::Base - Factory class for WSDL-based SOAP access
 Factory class for creating interface classes. Should probably be renamed to
 SOAP::WSDL::Factory::Interface...
 
+=head1 METHODS
+
+=head2 call
+
+Abstraction layer method between the generated interfaces and
+L<SOAP::WSDL::Client|SOAP::WSDL::Client>.
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2004-2007 Martin Kutter.
@@ -78,9 +85,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 501 $
+ $Rev: 838 $
  $LastChangedBy: kutterma $
- $Id: Base.pm 501 2008-01-26 20:23:32Z kutterma $
- $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Client/Base.pm $
+ $Id: Base.pm 838 2009-03-09 20:10:23Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/branches/Typemap/lib/SOAP/WSDL/Client/Base.pm $
 
 =cut
