@@ -1,26 +1,22 @@
 package SOAP::WSDL::Definitions;
-use utf8;
 use strict;
 use warnings;
-use Carp;
-use File::Basename;
-use File::Path;
 use List::Util qw(first);
 use Class::Std::Fast::Storable;
 use base qw(SOAP::WSDL::Base);
 
-our $VERSION='2.00_33';
+use version; our $VERSION = qv('2.00.99_1');
 
 my %types_of        :ATTR(:name<types>      :default<[]>);
 my %message_of      :ATTR(:name<message>    :default<[]>);
 my %portType_of     :ATTR(:name<portType>   :default<[]>);
 my %binding_of      :ATTR(:name<binding>    :default<[]>);
 my %service_of      :ATTR(:name<service>    :default<[]>);
-my %namespace_of    :ATTR(:name<namespace> :default<()>);
+my %namespace_of    :ATTR(:name<namespace>  :default<()>);
 
 # must be attr for Class::Std::Fast::Storable
-my %attributes_of :ATTR();
-%attributes_of = (
+#my %attributes_of :ATTR();
+my %attributes_of = (
     binding     => \%binding_of,
     message     => \%message_of,
     portType    => \%portType_of,
@@ -44,6 +40,7 @@ BLOCK: {
   }
 }
 
+
 1;
 
 =pod
@@ -72,7 +69,7 @@ Returns the service matching the namespace/localname pair passed as arguments.
 Accessors/Mutators for accessing / setting the E<gt>bindingE<lt> child
 element(s).
 
-=head2 find_service
+=head2 find_binding
 
 Returns the binding matching the namespace/localname pair passed as arguments.
 
@@ -94,7 +91,7 @@ Returns the portType matching the namespace/localname pair passed as arguments.
 Accessors/Mutators for accessing / setting the E<gt>messageE<lt> child
 element(s).
 
-=head2 find_service
+=head2 find_message
 
 Returns the message matching the namespace/localname pair passed as arguments.
 
@@ -118,10 +115,10 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 549 $
+ $Rev: 838 $
  $LastChangedBy: kutterma $
- $Id: Definitions.pm 549 2008-02-20 10:14:26Z kutterma $
- $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Definitions.pm $
+ $Id: Definitions.pm 838 2009-03-09 20:10:23Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/branches/Typemap/lib/SOAP/WSDL/Definitions.pm $
 
 =cut
 
