@@ -2,7 +2,7 @@ package SOAP::WSDL::Deserializer::SOM;
 use strict;
 use warnings;
 
-our $VERSION = '2.00_24';
+use version; our $VERSION = qv('2.00.99_1');
 our @ISA;
 
 eval {
@@ -13,6 +13,18 @@ or die "Cannot load SOAP::Lite.
 Cannot deserialize to SOM object without SOAP::Lite.
 Please install SOAP::Lite.";
 
+sub deserialize {
+    my $self = shift;
+    my $result = eval { $self->SUPER::deserialize(@_) };
+    if ($@) {
+        return SOAP::Fault->new(
+            faultactor => 'SOAP-ENV:Server',
+            faultstring => $@,
+        );
+    }
+    return $result;
+}
+
 sub generate_fault {
     my ($self, $args_from_ref) = @_;
     # code, message, detail, actor
@@ -37,7 +49,7 @@ SOAP::WSDL::Deserializer::SOM - Deserializer SOAP messages into SOM objects
  use SOAP::WSDL::Deserializer::SOM;
  use SOAP::WSDL::Factory::Deserializer;
  SOAP::WSDL::Factory::Deserializer->register( '1.1', __PACKAGE__ );
- 
+
 =head1 DESCRIPTION
 
 Deserializer for creating SOAP::Lite's SOM object as result of a SOAP call.
@@ -66,13 +78,24 @@ This may be XML including mixed content, attachements and other XML data not
 SOAP::WSDL::Deserializer::SOM is a subclass of L<SOAP::Deserializer|SOAP::Deserializer>
 from the L<SOAP::Lite|SOAP::Lite> package.
 
+=head1 METHODS
+
+=head2 deserialize
+
+Deserializes a XML sting into a SOAP::SOM object. Returns a SOAP::Fault object
+on deserialization errors.
+
+=head2 generate_fault
+
+Dies with a SOAP::Fault object.
+
 =head1 USAGE
 
-SOAP::WSDL::Deserializer will not auroregister itself - to use it for a particular
+SOAP::WSDL::Deserializer will not autoregister itself - to use it for a particular
 SOAP version just use the following lines:
 
  my $soap_version = '1.1'; # or '1.2', further versions may appear.
- 
+
  use SOAP::WSDL::Deserializer::SOM;
  use SOAP::WSDL::Factory::Deserializer;
  SOAP::WSDL::Factory::Deserializer->register( $soap_version, __PACKAGE__ );
@@ -85,8 +108,8 @@ SOAP version just use the following lines:
 
 =item * No on_fault handler
 
-You cannot specify what to do when an error occurs - SOAP::WSDL will die
-with a SOAP::Fault object on transport errors.
+You cannot specify what to do when an error occurs - SOAP::WSDL will return
+a SOAP::Fault object on transport errors.
 
 =back
 
@@ -99,6 +122,9 @@ with a SOAP::Fault object on transport errors.
 SOAP::WSDL::Deserializer::SOM will die with a SOAP::Fault object on calls
 to generate_fault.
 
+This also means that a SOAP::Fault may be thrown as exception when using
+
+
 =back
 
 =head1 LICENSE AND COPYRIGHT
@@ -114,9 +140,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 391 $
+ $Rev: 838 $
  $LastChangedBy: kutterma $
- $Id: SOM.pm 391 2007-11-17 21:56:13Z kutterma $
- $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Deserializer/SOM.pm $
+ $Id: SOM.pm 838 2009-03-09 20:10:23Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/branches/Typemap/lib/SOAP/WSDL/Deserializer/SOM.pm $
 
 =cut
