@@ -2,7 +2,7 @@ package SOAP::WSDL::Factory::Deserializer;
 use strict;
 use warnings;
 
-our $VERSION = '2.00_24';
+use version; our $VERSION = qv('2.00.99_1');
 
 my %DESERIALIZER = (
     '1.1' => 'SOAP::WSDL::Deserializer::XSD',
@@ -47,10 +47,10 @@ SOAP::WSDL::Factory::Deserializer - Factory for retrieving Deserializer objects
  # in deserializer class:
  package MyWickedDeserializer;
  use SOAP::WSDL::Factory::Deserializer;
- 
+
  # register class as deserializer for SOAP1.2 messages
  SOAP::WSDL::Factory::Deserializer->register( '1.2' , __PACKAGE__ );
- 
+
 =head1 DESCRIPTION
 
 SOAP::WSDL::Factory::Deserializer serves as factory for retrieving
@@ -131,6 +131,17 @@ passed as a single hash ref:
  role       - The fault role (actor in SOAP1.1)
  message    - The fault message (faultstring in SOAP1.1)
 
+=item * init_from_caller (optional)
+
+This method is called from the caller (usually a SOAP::WSDL::Client or a 
+SOAP::WSDL::Server subclass) and allows the deserializer to initialize itself.
+
+It is currently called with the following parameters: 
+
+ $caller - the calling object
+ $method - a method info hash ref, containing the parts and stuff of the
+           SOAP method invoked.
+
 =back
 
 =head1 LICENSE AND COPYRIGHT
@@ -150,5 +161,5 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
  $LastChangedBy: kutterma $
  $Id: Serializer.pm 176 2007-08-31 15:28:29Z kutterma $
  $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Factory/Serializer.pm $
- 
+
 =cut
