@@ -2,7 +2,7 @@ package SOAP::WSDL::Factory::Serializer;
 use strict;
 use warnings;
 
-our $VERSION='2.00_24';
+use version; our $VERSION = qv('2.00.99_1');
 
 my %SERIALIZER = (
     '1.1' => 'SOAP::WSDL::Serializer::XSD',
@@ -16,7 +16,7 @@ sub register {
 
 sub get_serializer {
     my ($self, $args_of_ref) = @_;
-
+    $args_of_ref->{ soap_version } ||= '1.1';
     # sanity check
     die "no serializer registered for SOAP version $args_of_ref->{ soap_version }"
         if not exists ($SERIALIZER{ $args_of_ref->{ soap_version } });
@@ -46,10 +46,10 @@ SOAP::WSDL::Factory::Serializer - Factory for retrieving serializer objects
  # in serializer class:
  package MyWickedSerializer;
  use SOAP::WSDL::Factory::Serializer;
- 
+
  # register as serializer for SOAP1.2 messages
  SOAP::WSDL::Factory::Serializer->register( '1.2' , __PACKAGE__ );
- 
+
 =head1 DESCRIPTION
 
 SOAP::WSDL::Factory::Serializer serves as factory for retrieving
@@ -138,9 +138,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 391 $
+ $Rev: 838 $
  $LastChangedBy: kutterma $
- $Id: Serializer.pm 391 2007-11-17 21:56:13Z kutterma $
- $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Factory/Serializer.pm $
- 
+ $Id: Serializer.pm 838 2009-03-09 20:10:23Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/branches/Typemap/lib/SOAP/WSDL/Factory/Serializer.pm $
+
 =cut
