@@ -2,6 +2,8 @@ package SOAP::WSDL::Generator::Iterator::WSDL11;
 use strict; use warnings;
 use Class::Std::Fast;
 
+use version; our $VERSION = qv('2.00.99_1');
+
 my %definitions_of  :ATTR(:name<definitions>    :default<[]>);
 my %nodes_of        :ATTR(:name<nodes>          :default<[]>);
 
@@ -71,8 +73,10 @@ my %METHOD_OF = (
             $node->get_type()
                 ? do {
                     die "unsupported global type <"
-                        . $node->get_type . "> found in part ". $node->get_name();
-                    $types->find_type( $node->expand($node->get_type) )
+                        . $node->get_type . "> found in part <". $node->get_name() . ">\n"
+                        . "Looks like a rpc/literal WSDL, which is not supported by SOAP::WSDL\n";
+                    ## use this once we can auto-generate an element for RPC bindings
+                    # $types->find_type( $node->expand($node->get_type) )
                 }
                 : (),
             $node->get_element()
@@ -242,8 +246,8 @@ The nodes are returned in the order denoted in the following example:
     </service>
  </definitions>
 
-You should not rely too much on this order - it may change. Even though, the
-current order will probably remain, but the nodes currently skipped might
+You should not rely too much on this order - it may change. Even though the
+current order will probably remain, the nodes currently skipped might
 be returned somewhere along the path.
 
 
