@@ -1,11 +1,11 @@
 package SOAP::WSDL::Generator::Template;
-use strict;
-use Template;
+use strict; use warnings;
+use Template 2.18;
 use Class::Std::Fast::Storable;
 use Carp;
 use SOAP::WSDL::Generator::PrefixResolver;
 
-use version; our $VERSION = qv(2.00_33);
+use version; our $VERSION = qv('2.00.99_1');
 
 my %tt_of               :ATTR(:get<tt>);
 my %definitions_of      :ATTR(:name<definitions>        :default<()>);
@@ -39,11 +39,13 @@ sub _process :PROTECTED {
         INCLUDE_PATH => $INCLUDE_PATH_of{ $ident },
         OUTPUT_PATH => $OUTPUT_PATH_of{ $ident },
         PLUGIN_BASE => 'SOAP::WSDL::Generator::Template::Plugin',
-    );
+    )
+        or die Template->error();
 
     $tt->process( $template,
     {
         context => {
+            prefix_resolver_class => $prefix_resolver_class_of{ $$self },
             prefix_resolver => $prefix_resolver_class_of{ $$self }->new({
                 namespace_prefix_map => {
                     'http://www.w3.org/2001/XMLSchema' => 'SOAP::WSDL::XSD::Typelib::Builtin',
@@ -68,4 +70,40 @@ sub _process :PROTECTED {
         or croak $INCLUDE_PATH_of{ $ident }, '\\', $template, ' ', $tt->error();
 }
 
-1;
\ No newline at end of file
+1;
+
+=pod
+
+=head1 NAME
+
+SOAP::WSDL::Generator::Template - Template-based code generator
+
+=head1 DESCRIPTION
+
+SOAP::WSDL's template based code generator
+
+Base class for writing template based generators
+
+=head1 AUTHOR
+
+Replace the whitespace by @ for E-Mail Address.
+
+ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2008, 2009 Martin Kutter.
+
+This file is part of SOAP-WSDL. You may distribute/modify it under
+the same terms as perl itself
+
+=head1 Repository information
+
+ $Id: WSDLParser.pm 770 2009-01-24 22:55:54Z kutterma $
+
+ $LastChangedDate: 2009-01-24 23:55:54 +0100 (Sa, 24 Jan 2009) $
+ $LastChangedRevision: 770 $
+ $LastChangedBy: kutterma $
+
+ $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Expat/WSDLParser.pm $
+
