@@ -3,21 +3,26 @@ use strict;
 use warnings;
 use Carp qw(confess);
 use Class::Std::Fast::Storable constructor => 'none';
+use Scalar::Util qw(blessed);
+use version; our $VERSION = qv('2.00.99_1');
 
 my %namespace_prefix_map_of :ATTR(:name<namespace_prefix_map>   :default<{}>);
 my %namespace_map_of        :ATTR(:name<namespace_map>          :default<{}>);
 my %prefix_of               :ATTR(:name<prefix>                 :default<()>);
 my %prefix_resolver_of      :ATTR(:name<prefix_resolver>        :default<()>);
 
+my %prefix_resolver_class_of    :ATTR(:name<prefix_resolver_class>  :default<()>);
+
+my %definitions_of          :ATTR(:name<definitions>            :default<()>);
+
 # create a singleton
-sub load {               # called as MyPlugin->load($context)
+sub load {              # called as MyPlugin->load($context)
     my ($class, $context, @arg_from) = @_;
     my $stash = $context->stash();
     my $self = bless \do { my $o = Class::Std::Fast::ID() }, $class;
-#    $self->set_namespace_map( $stash->{ context }->{ namespace_map });
-#    $self->set_namespace_prefix_map( $stash->{ context }->{ namespace_prefix_map });
-#    $self->set_prefix( $stash->{ context }->{ prefix });
+    $self->set_prefix_resolver_class( $stash->{ context }->{ prefix_resolver_class });
     $self->set_prefix_resolver( $stash->{ context }->{ prefix_resolver });
+    $self->set_definitions( $stash->{ definitions });
     return $self;       # returns 'MyPlugin'
 }
 
@@ -27,10 +32,8 @@ sub new {
     my ($class, $arg_ref) = @_;
 
     my $self = bless \do { my $o = Class::Std::Fast::ID() }, $class;
-#    $self->set_namespace_map( $arg_ref->{ namespace_map });
-#    $self->set_namespace_prefix_map( $arg_ref->{ namespace_prefix_map });
-#    $self->set_prefix( $arg_ref->{ prefix });
     $self->set_prefix_resolver( $arg_ref->{ prefix_resolver });
+    $self->set_definitions( $arg_ref->{ definitions });
     return $self;       # returns 'MyPlugin'
 }
 
@@ -38,10 +41,10 @@ sub _get_prefix {
     my ($self, $type, $node) = @_;
     my $namespace = defined ($node)
         ? ref($node)
-            ? $node->get_targetNamespace
+            ? $node->get_targetNamespace()
             : $node
         : undef;
-    return $self->get_prefix_resolver->resolve_prefix(
+    return $self->get_prefix_resolver()->resolve_prefix(
         $type,
         $namespace,
         ref($node)
@@ -50,27 +53,18 @@ sub _get_prefix {
      );
 }
 
-#sub _get_prefix {
-#    my ($self, $type, $namespace) = @_;
-#    return $prefix_of{ $$self }->{ $type }
-#        if not defined($namespace);
-#    return $namespace_prefix_map_of{ $$self }->{ $namespace }
-#        || ( ($namespace_map_of{ $$self }->{ $namespace })
-#            ? join ('::', $prefix_of{ $$self }->{ $type }, $namespace_map_of{ $$self }->{ $namespace })
-#            : $prefix_of{ $$self }->{ $type }
-#        );
-#}
-
 sub create_xsd_name {
-    my ($self,$element) = @_;
-    my $name = $self->_resolve_prefix($element) . '::'
-        . $element->get_name();
+    my ($self, $node) = @_;
+    confess "no node $node" if not defined($node)
+        or $node eq "";
+    my $name = $self->_resolve_prefix($node) #. '::'
+        . $node->get_name();
     return $self->perl_name( $name );
 }
 
 sub create_typemap_name {
     my ($self, $node) = @_;
-    my $name = $self->_get_prefix('typemap') . '::'
+    my $name = $self->_get_prefix('typemap') #. '::'
         . $node->get_name();
     return $self->perl_name( $name );
 }
@@ -79,10 +73,9 @@ sub create_server_name {
     my ($self, $server, $port) = @_;
     my $port_name = $port->get_name();
     $port_name =~s{\A (?:.+)\. ([^\.]+) \z}{$1}x;
-    my $name = join('::',
+    my $name = join( q{},
         $self->_get_prefix('server', $server),
-        $server->get_name(),
-        $port_name
+         join( '::', $server->get_name(), $port_name)
     );
     return $self->perl_name( $name );
 }
@@ -91,17 +84,16 @@ sub create_interface_name {
     my ($self, $server, $port) = @_;
     my $port_name = $port->get_name();
     $port_name =~s{\A (?:.+)\. ([^\.]+) \z}{$1}x;
-    my $name = join('::',
+    my $name = join( q{},
         $self->_get_prefix('interface', $server),
-        $server->get_name(),
-        $port_name
+        join( '::', $server->get_name(), $port_name )
     );
     return $self->perl_name( $name );
 }
 
 sub _resolve_prefix {
     my ($self, $node) = @_;
-    confess "no node" if not $node;
+
     if ($node->isa('SOAP::WSDL::XSD::Builtin')) {
         return $self->_get_prefix('type', $node)
     }
@@ -121,8 +113,16 @@ sub _resolve_prefix {
 sub perl_name {
     my $self = shift;
     my $name = shift;
-    $name =~s{[\-]}{_}xmsg;
-    $name =~s{[\.]}{::}xmsg;
+    $name =~s{\-}{_}xmsg;
+    $name =~s{\.}{::}xmsg;
+    return $name;
+}
+
+sub perl_var_name {
+    my $self = shift;
+    my $name = shift;
+    $name =~s{\-}{_}xmsg;
+    $name =~s{\.}{__}xmsg;
     return $name;
 }
 
@@ -132,8 +132,10 @@ sub create_subpackage_name {
     my $type        = ref $arg_ref eq 'HASH' ? $arg_ref->{ value } : $arg_ref;
 
     my @name_from = $type->get_name() || (); ;
-    my $parent = $type;
-    my $top_node = $parent;
+
+    # search for top node in tree (the one directly below the Schema)
+	my $parent = $type;
+	my $top_node = $parent;
     if (! $parent->get_parent()->isa('SOAP::WSDL::XSD::Schema') ) {
         NAMES: while ($parent = $parent->get_parent()) {
             $top_node = $parent;
@@ -144,8 +146,13 @@ sub create_subpackage_name {
         }
     }
     # create name for top node
+    die "No top node found" if not defined $top_node;
     my $top_node_name = $self->create_xsd_name($top_node);
     my $package_name = join('::_', $top_node_name , (@name_from) ? join('::', @name_from) : () );
+
+    # replace dots by :: in name - subpackage names may include dots, too
+    $package_name =~s{\.}{::}xg;
+
     return $package_name;
 }
 
@@ -153,6 +160,24 @@ sub create_xmlattr_name {
     return join '::', shift->create_subpackage_name(shift), 'XmlAttr';
 }
 
+sub element_name {
+    my $self = shift;
+    my $element = shift;
+
+    confess "no element object" unless blessed $element;
+
+    my $name = $element->get_name();
+    if (! $name) {
+        while (my $ref = $element->get_ref()) {
+            $element = $self->get_definitions()->first_types()
+                ->find_element($element->expand( $ref ) );
+            $name = $element->get_name();
+            last if ($name);
+        }
+    }
+    return $name;
+}
+
 1;
 
 =pod
