@@ -1,7 +1,9 @@
 package SOAP::WSDL::Transport::HTTP;
-use strict;
+use strict; use warnings;
 use base qw(LWP::UserAgent);
 
+use version; our $VERSION = qv('2.00.99_1');
+
 # create methods normally inherited from SOAP::Client
 SUBFACTORY: {
     no strict qw(refs);
@@ -14,6 +16,10 @@ SUBFACTORY: {
     }
 }
 
+sub _agent {
+    return qq[SOAP::WSDL $VERSION];
+}
+
 sub send_receive {
     my ($self, %parameters) = @_;
     my ($envelope, $soap_action, $endpoint, $encoding, $content_type) =
@@ -21,9 +27,10 @@ sub send_receive {
 
     $encoding = defined($encoding)
         ? lc($encoding)
-        : 'utf8';
+        : 'utf-8';
 
-    $content_type = 'text/xml' if not defined($content_type);
+    $content_type = "text/xml; charset=$encoding"
+        if not defined($content_type);
     # what's this all about?
     # unfortunately combination of LWP and Perl 5.6.1 and later has bug
     # in sending multibyte characters. LWP uses length() to calculate
@@ -46,7 +53,7 @@ sub send_receive {
 
     my $request = HTTP::Request->new( 'POST',
         $endpoint,
-        [   'Content-Type', "$content_type; charset=$encoding",
+        [   'Content-Type', "$content_type",
             'Content-Length', $bytelength,
             'SOAPAction', $soap_action,
         ],
@@ -88,10 +95,10 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 399 $
+ $Rev: 838 $
  $LastChangedBy: kutterma $
- $Id: HTTP.pm 399 2007-11-19 19:20:52Z kutterma $
- $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Transport/HTTP.pm $
- 
+ $Id: HTTP.pm 838 2009-03-09 20:10:23Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/branches/Typemap/lib/SOAP/WSDL/Transport/HTTP.pm $
+
 =cut
 
