@@ -4,6 +4,11 @@ use warnings;
 use Class::Std::Fast::Storable;
 use base qw(SOAP::WSDL::Base);
 
+use version; our $VERSION = qv('2.00.99_1');
+
+# only used in SOAP::WSDL - will be obsolete once SOAP::WSDL uses the
+# generative approach, too
+
 sub serialize {
     my ($self, $name, $value, $opt) = @_;
     my $xml;
@@ -18,7 +23,7 @@ sub serialize {
         my $prefix = $prefix_of{ $ns }
             || die 'No prefix found for namespace '. $ns;
         $xml .= ' type="' . $prefix . ':'
-          . $self->get_name() . '"' if ($self->get_name() );
+          . $self->get_name() . '"';
     }
 
     if (defined $value) {
