@@ -4,7 +4,7 @@ use warnings;
 use Class::Std::Fast::Storable;
 use base qw(SOAP::WSDL::Base);
 
-our $VERSION=q{2.00_33};
+use version; our $VERSION = qv('2.00.99_1');
 
 # child elements
 my %attributeGroup_of   :ATTR(:name<attributeGroup>  :default<[]>);
@@ -14,9 +14,9 @@ my %group_of            :ATTR(:name<group>           :default<[]>);
 my %type_of             :ATTR(:name<type>            :default<[]>);
 
 # attributes
-my %attributeFormDefault_of :ATTR(:name<attributeFormDefault> :default<()>);
+my %attributeFormDefault_of :ATTR(:name<attributeFormDefault> :default<unqualified>);
 my %blockDefault_of         :ATTR(:name<blockDefault>         :default<()>);
-my %elementFormDefault_of   :ATTR(:name<elementFormDefault>   :default<()>);
+my %elementFormDefault_of   :ATTR(:name<elementFormDefault>   :default<unqualified>);
 my %finalDefault_of         :ATTR(:name<finalDefault>         :default<()>);
 my %version_of              :ATTR(:name<version>              :default<()>);
 
@@ -39,10 +39,10 @@ my %version_of              :ATTR(:name<version>              :default<()>);
 # alias type with all variants
 # AUTOMETHOD is WAY too slow..
 {
-    no strict qw/refs/;
+    no strict qw(refs);
     for my $name (qw(simpleType complexType) ) {
-        *{ "set_$name" } = \&set_type;
-        *{ "get_$name" } = \&get_type;
+        *{ "set_$name" }  = \&set_type;
+        *{ "get_$name" }  = \&get_type;
         *{ "push_$name" } = \&push_type;
         *{ "find_$name" } = \&find_type;
     }
@@ -56,8 +56,11 @@ sub push_type {
 
 sub find_element {
     my ($self, @args) = @_;
+
     my @found_at = grep {
         $_->get_targetNamespace() eq $args[0] &&
+#		warn $_->get_name() . " default NS:" . $_->get_xmlns()->{'#default'} . "\n";
+#		$_->get_xmlns()->{'#default'} eq $args[0] &&
         $_->get_name() eq $args[1]
     }
     @{ $element_of{ ident $self } };
@@ -66,8 +69,10 @@ sub find_element {
 
 sub find_type {
     my ($self, @args) = @_;
+
     my @found_at = grep {
         $_->get_targetNamespace() eq $args[0] &&
+#        $_->get_xmlns()->{'#default'} eq $args[0] &&
         $_->get_name() eq $args[1]
     }
     @{ $type_of{ ident $self } };
