@@ -6,8 +6,12 @@ use SOAP::WSDL::XSD::Schema;
 use SOAP::WSDL::XSD::Builtin;
 use base qw(SOAP::WSDL::XSD::Schema);
 
+use version; our $VERSION = qv('2.00.99_1');
+
 # all builtin types - add validation (e.g. content restrictions) later...
 my %BUILTINS = (
+    'anyType'           => {},
+    'anySimpleType'     => {},
     'anyURI'            => {},
     'boolean'           => {},
     'base64Binary'      => {},
@@ -61,6 +65,9 @@ sub START {
         $self->push_type( SOAP::WSDL::XSD::Builtin->new({
                 name => $name,
                 targetNamespace => 'http://www.w3.org/2001/XMLSchema',
+                xmlns => {
+                	'#default' => 'http://www.w3.org/2001/XMLSchema',
+                }
             } )
         );
     }
@@ -96,10 +103,10 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 583 $
+ $Rev: 838 $
  $LastChangedBy: kutterma $
- $Id: Builtin.pm 583 2008-03-24 07:44:06Z kutterma $
- $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/XSD/Schema/Builtin.pm $
+ $Id: Builtin.pm 838 2009-03-09 20:10:23Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/branches/Typemap/lib/SOAP/WSDL/XSD/Schema/Builtin.pm $
 
 =cut
 
