@@ -4,59 +4,89 @@ use strict;
 use warnings;
 use Carp;
 use SOAP::WSDL::XSD::Typelib::Builtin;
-use Scalar::Util qw(blessed refaddr);
+use Scalar::Util qw(blessed);
+use Data::Dumper;
 require Class::Std::Fast::Storable;
 
 use base qw(SOAP::WSDL::XSD::Typelib::Builtin::anyType);
 
-our $VERSION = '2.00_33';
+use version; our $VERSION = qv('2.00.99_1');
 
-my %ELEMENTS_FROM;
-my %ATTRIBUTES_OF;
-my %CLASSES_OF;
+# remove in 2.1
+our $AS_HASH_REF_WITHOUT_ATTRIBUTES = 0;
+
+my %ELEMENT_FORM_QUALIFIED_OF;  # denotes whether elements are qualified
+my %ELEMENTS_FROM;      # order of elements in a class
+my %ATTRIBUTES_OF;      # references to value hashes
+my %CLASSES_OF;         # class names of elements in a class
+my %NAMES_OF;           # XML names of elements in a class
+
+
+# XML Attribute handling
+my %xml_attr_of     :ATTR();
+
+# Namespace handling
+my %xmlns_of        :ATTR();
+
+our $MAY_HAVE_CHILDREN = 1;
 
 # don't you ever dare to use this !
+our $___classes_of_ref = \%CLASSES_OF;
 our $___attributes_of_ref = \%ATTRIBUTES_OF;
+our $___xml_attribute_of_ref = \%xml_attr_of;
 
 # STORABLE_ methods for supporting Class::Std::Fast::Storable.
 # We could also handle them via AUTOMETHOD,
 # but AUTOMETHOD should always croak...
-# Do we really need this ?
-# ... looks like we do...
-sub STORABLE_freeze_pre {}
-sub STORABLE_freeze_post {}
-sub STORABLE_thaw_pre {}
-sub STORABLE_thaw_post {}
+# Actually, AUTOMETHOD is faster (~1%) if Class::Std::Fast is loaded
+# properly, and slower (~10%) if not.
+# Hmmm. Trade 1% for 10?
+
+my %STORABLE_METHODS = (
+    STORABLE_freeze_pre => undef,
+    STORABLE_freeze_post => undef,
+    STORABLE_thaw_pre => undef,
+    STORABLE_thaw_post => undef,
+);
 
 # for error reporting. Eases working with data objects...
 sub AUTOMETHOD {
-    my ($self, $ident, @args_from) = @_;
+    # return before unpacking @_ for speed reasons
+    return if exists $STORABLE_METHODS{$_};
 
+    my ($self, $ident, @args_from) = @_;
     my $class = ref $self || $self or die "Cannot call AUTOMETHOD as function";
+
+    # Test whether we're called from ->can()
+    my @caller = caller(1);
+
+    # return if not called by AUTOLOAD - caller must be something like can()
+    # Unfortunately we cannot test for "UNIVERSAL::can", as it gets overwritten
+    # by both Class::Std and Class::Std::Fast, and we don't know the loading
+    # order (Class::Std::Fast should be loaded before for maximum speedup)
+    return if $caller[3] ne 'Class::Std::AUTOLOAD';
+
     confess "Can't locate object method \"$_\" via package \"$class\". \n"
         . "Valid methods are: "
         . join(', ', map { ("get_$_" , "set_$_") } keys %{ $ATTRIBUTES_OF{ $class } })
         . "\n"
 }
 
-# Attribute handling
-my %xml_attr_of :ATTR();
-
 sub attr {
-    my $self = shift;
-    my $class = $self->__get_attr_class()
+    # We're working on @_ for speed.
+    # Normally, the first line would look like this:
+    # my $self = shift;
+
+    my $class = $_[0]->__get_attr_class()
         or return;
 
-    # disable strictness - in perl 5.10 %{ "$foo\::_bar" } triggers a
-    # symbolic reference error with strictness enabled
-    no strict qw(refs);
-    # die "$class has no attributes" if not defined %{ "$class\::_ATTR::"};
-    if (@_) {
-        # setter
-        return $xml_attr_of{ $$self } = $class->new(@_);
+    # pass arguments to attributes constructor (if any);
+    # lets attr($foo) work as setter
+    if ($_[1]) {
+        return $xml_attr_of{ ${$_[0]} } = $class->new($_[1]);
     }
-    return $xml_attr_of{ $$self } if exists $xml_attr_of{ $$self };
-    return $xml_attr_of{ $$self } = $class->new();
+    return $xml_attr_of{ ${$_[0]} } if exists $xml_attr_of{ ${$_[0]} };
+    return $xml_attr_of{ ${$_[0]} } = $class->new();
 }
 
 sub serialize_attr {
@@ -64,30 +94,50 @@ sub serialize_attr {
     return $xml_attr_of{ ${ $_[0] } }->serialize();
 }
 
+# TODO: are complextypes are always true ?
+sub as_bool :BOOLIFY { 1 }
+
 sub as_hash_ref {
-    my $self = shift;
-    my $attributes_ref = $ATTRIBUTES_OF{ ref $self };
-    my $ident = ident $self;
+    # we're working on $_[0] for speed (as always...)
+    #
+    # Normally the first line would read:
+    # my ($self, $ignore_attributes) = @_;
+    #
+    my $attributes_ref = $ATTRIBUTES_OF{ ref $_[0] };
 
     my $hash_of_ref = {};
-    foreach my $attribute (keys %{ $attributes_ref }) {
-        next if not defined $attributes_ref->{ $attribute }->{ $ident };
-        my $value = $attributes_ref->{ $attribute }->{ $ident };
+    if ($_[0]->isa('SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType')) {
+        $hash_of_ref->{ value } = $_[0]->get_value();
+    }
+    else {
+        foreach my $attribute (keys %{ $attributes_ref }) {
+            next if not defined $attributes_ref->{ $attribute }->{ ${ $_[0] } };
+            my $value = $attributes_ref->{ $attribute }->{ ${ $_[0] } };
 
-        $hash_of_ref->{ $attribute } = blessed $value
-            ? $value->isa('SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType')
-                ? $value
-                : $value->as_hash_ref()
-            : ref $value eq 'ARRAY'
-                ? [
-                    map {
-                        $_->isa('SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType')
-                            ? $_
-                            : $_->as_hash_ref()
-                    } @{ $value }
-                ]
-                : die "Neither blessed obj nor list ref";
-    };
+            $hash_of_ref->{ $attribute } = blessed $value
+                ? $value->isa('SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType')
+                    ? $value->get_value()
+                    : $value->as_hash_ref($_[1])
+                : ref $value eq 'ARRAY'
+                    ? [
+                        map {
+                            $_->isa('SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType')
+                                ? $_->get_value()
+                                : $_->as_hash_ref($_[1])
+                        } @{ $value }
+                    ]
+                    : die "Neither blessed obj nor list ref";
+        };
+    }
+
+    # $AS_HASH_REF_WITHOUT_ATTRIBUTES is deprecated by NOW and will be removed
+    # in 2.1
+    return $hash_of_ref if $_[1] or $AS_HASH_REF_WITHOUT_ATTRIBUTES;
+
+
+    if (exists $xml_attr_of{ ${ $_[0] } }) {
+        $hash_of_ref->{ xmlattr } = $xml_attr_of{ ${ $_[0] } }->as_hash_ref();
+    }
 
     return $hash_of_ref;
 }
@@ -96,9 +146,10 @@ sub as_hash_ref {
 # call as __PACKAGE__->_factory
 sub _factory {
     my $class = shift;
-    $ELEMENTS_FROM{ $class } = shift;
-    $ATTRIBUTES_OF{ $class } = shift;
-    $CLASSES_OF{ $class } = shift;
+    $ELEMENTS_FROM{ $class }    = shift;
+    $ATTRIBUTES_OF{ $class }    = shift;
+    $CLASSES_OF{ $class }       = shift;
+    $NAMES_OF{ $class }         = shift;
 
     no strict qw(refs);
     no warnings qw(redefine);
@@ -152,7 +203,11 @@ sub _factory {
         #  d) we should also die for non-blessed non-ARRAY/HASH references in
         #     lists but don't do yet - oh my !
 
-        *{ "$class\::set_$name" } = sub {
+        # keep in sync with Generator::Template::Plugin::XSD - maybe use
+        # function to allow substituting via symbol table...
+        my $method_name = $name;
+        $method_name =~s{[\.\-]}{_}xmsg;
+        *{ "$class\::set_$method_name" } = sub {
             if (not $#_) {
                 delete $attribute_ref->{ ${ $_[0] } };
                 return;
@@ -174,8 +229,9 @@ sub _factory {
                          ]
                     : $is_ref eq 'HASH'
                         ?  $type->new( $_[1] )
-                        # neither ARRAY nor HASH - probably an object...
-                        :  ($is_ref eq $type)               # of required type ? ->isa would be a better test...
+                        # neither ARRAY nor HASH - probably an object... -
+                        # do we need to test for it being blessed?
+                        :  blessed $_[1] && $_[1]->isa($type)              # of required type ?
                             ? $_[1]                         # use it
                             : die croak "cannot use $is_ref reference as value for $name - $type required"
 
@@ -184,7 +240,7 @@ sub _factory {
             return;
         };
 
-        *{ "$class\::add_$name" } = sub {
+        *{ "$class\::add_$method_name" } = sub {
             warn "attempting to add empty value to " . ref $_[0]
                 if not defined $_[1];
 
@@ -210,25 +266,47 @@ sub _factory {
     # TODO Could be moved as normal method into base class, e.g. here.
     # Hmm. let's see...
     *{ "$class\::new" } = sub {
-        my $self = bless \(my $o = Class::Std::Fast::ID()), $_[0];
         # We're working on @_ for speed.
         # Normally, the first line would look like this:
-        # my ($self, $ident, $args_of) = @_;
+        # my ($class, $args_of) = @_;
         #
         # The hanging side comment show you what would be there, then.
 
+        # Read as:
+        # my $self = bless \(my $o = Class::Std::Fast::ID()), $class;
+        my $self = bless \(my $o = Class::Std::Fast::ID()), $_[0];
+
+        # Set attributes if passed via { xmlattr => \%attributes }
+        #
+        # This works just because
+        #    a) xmlattr cannot be used as valid XML identifier (it starts
+        #       with "xml" which is banned by the XML schema standard)
+        #    b) $o->attr($attribute_ref) passes $attribute_ref to the
+        #       attribute object's constructor
+        #    c) we are in the object's constructor here (which means that)
+        #       no attributes object can have been legally constructed
+        #       before.
+        if (exists $_[1]->{xmlattr}) {                      # $args_of->{xmlattr}
+            $self->attr(delete $_[1]->{xmlattr});
+        }
+
         # iterate over keys of arguments
         # and call set appropriate field in clase
         map { ($ATTRIBUTES_OF{ $class }->{ $_ })
             ? do {
-                 my $method = "set_$_";
-                 $self->$method( $_[1]->{ $_ } );               # ( $args_of->{ $_ } );
+                my $method = "set_$_";
+
+                # keep in sync with Generator::Template::Plugin::XSD - maybe use
+                # function to allow substituting via symbol table...
+                $method =~s{[\.\-]}{_}xmsg;
+
+                $self->$method( $_[1]->{ $_ } );               # ( $args_of->{ $_ } );
            }
            : $_ =~ m{ \A              # beginning of string
                       xmlns           # xmlns
                 }xms        # get_elements is inlined for performance.
                 ? ()
-                : do { use Data::Dumper;
+                : do {
                      croak "unknown field $_ in $class. Valid fields are:\n"
                      . join(', ', @{ $ELEMENTS_FROM{ $class } }) . "\n"
                      . "Structure given:\n" . Dumper @_ };
@@ -247,6 +325,7 @@ sub _factory {
     *{ "$class\::_serialize" } = sub {
         my $ident = ${ $_[0] };
         my $option_ref = $_[1];
+        
         # return concatenated return value of serialize call of all
         # elements retrieved from get_elements expanding list refs.
         return \join q{} , map {
@@ -255,20 +334,89 @@ sub _factory {
             # do we have some content
             if (defined $element) {
                 $element = [ $element ] if not ref $element eq 'ARRAY';
-                my $name = $_;
+                # from 2.00.09 on $NAMES_OF is filled - use || $_; for
+                # backward compatibility
+                my $name = $NAMES_OF{$class}->{$_} || $_;
 
+                # get element's class for comparing with elements
+                my $element_class = $CLASSES_OF{$class}->{$_};
+
+                my $target_namespace = $_[0]->get_xmlns();
                 map {
+                    my %type_info = ($element_class ne ref $_)
+                        ? (derived => 1)
+                        : ();
+
                     # serialize element elements with their own serializer
                     # but name them like they're named here.
+                    # TODO: check. element ref="" has a name???
                     if ( $_->isa( 'SOAP::WSDL::XSD::Typelib::Element' ) ) {
-                            $_->serialize({ name => $name });
+                            # serialize elements of different namespaces
+                            # with namespace declaration
+                            ($target_namespace ne $_->get_xmlns())
+                                ? $_->serialize({ name => $name, qualified => 1, %type_info })
+                                : $_->serialize({ name => $name
+                                    , %type_info
+                                });
                     }
                     # serialize complextype elments (of other types) with their
                     # serializer, but add element tags around.
                     else {
-                        join q{}, $_->start_tag({ name => $name , %{ $option_ref } })
-                            , $_->serialize($option_ref)
-                            , $_->end_tag({ name => $name , %{ $option_ref } });
+                        # TODO: check whether we have to handle
+                        # types from different namespaces special, too
+                        if (!defined $ELEMENT_FORM_QUALIFIED_OF{ $class }
+                            or $ELEMENT_FORM_QUALIFIED_OF{ $class }
+                        ) {
+                            # handle types from different namespaces
+                            #
+                            # serialize with last namespace put on stack
+                            # if the last namespace is a change from the
+                            # before-last
+                            #
+                            if (
+                                exists $option_ref->{ xmlns_stack } 
+                                && (scalar @{ $option_ref->{ xmlns_stack } } >= 2) 
+                                && ($option_ref->{ xmlns_stack }->[-1] ne $option_ref->{ xmlns_stack }->[-2])) {
+                                # warn "New namespace: ", $option_ref->{ xmlns_stack }->[-1]; 
+                                join q{}, $_->start_tag({ name => $name , 
+                                    xmlns => $option_ref->{ xmlns_stack }->[-1], 
+                                    %{ $option_ref }, %type_info })
+                                    , $_->serialize({ %{ $option_ref }, %type_info })
+                                    , $_->end_tag({ name => $name , %{ $option_ref } });
+                            }
+                            else {
+                                join q{}, $_->start_tag({ name => $name , %{ $option_ref }, %type_info })
+                                    , $_->serialize({ %{ $option_ref }, %type_info })
+                                    , $_->end_tag({ name => $name , %{ $option_ref } });
+                            }
+                        }
+                        else {
+                            # in elementFormDefault="unqualified" mode,
+                            # the serialize method has to set
+                            # xmnlns="" on all elements inside a ComplexType
+                            #
+                            # Other serializers usually use prefixes 
+                            # for "unqualified" and just omit all prefixes
+                            # for inner elements 
+                            
+                            # check whether we "had" a xmlns around
+                            my $set_xmlns = delete $option_ref->{xmlns};
+                            
+                            # serialize start tag with xmlns="" if out parent
+                            # did not do that
+                            join q{}, $_->start_tag({
+                                    name => $name,
+                                    %{ $option_ref },
+                                    %type_info,
+                                    (! defined $set_xmlns)
+                                        ? (xmlns => "")
+                                        : ()
+                                })
+                                # add xmlns = "" to child serialize options
+                                # to avoid putting xmlns="" everywhere
+                                , $_->serialize({ %{$option_ref}, xmlns => "" })
+                                , $_->end_tag({ name => $name , %{ $option_ref } });
+                        }
                     }
                 } @{ $element }
             }
@@ -285,17 +433,26 @@ sub _factory {
     };
 }
 
-# just a fallback
+sub _set_element_form_qualified {
+    $ELEMENT_FORM_QUALIFIED_OF{ $_[0] } = $_[1];
+}
+
+# Just as fallback: return no attribute set class as default.
+# Subclasses may override
 sub __get_attr_class {};
 
 # hidden complex serializer
 sub __serialize_complex {
     # we work on @_ for performance.
     $_[1] ||= {};                                   # $option_ref
-
+    
+    push @{ $_[1]->{ xmlns_stack } }, $_[0]->get_xmlns();
+    
     # get content first (pass by reference to avoid copying)
     my $content_ref = $_[0]->_serialize($_[1]);     # option_ref
 
+    pop @{ $_[1]->{ xmlns_stack } };
+
     # do we have a empty element ?
     return $_[0]->start_tag({ %{ $_[1] }, empty => 1 })
         if not length ${ $content_ref };
@@ -303,6 +460,10 @@ sub __serialize_complex {
     return join q{}, $_[0]->start_tag($_[1]), ${ $content_ref }, $_[0]->end_tag();
 }
 
+sub get_xmlns {
+    return q{}
+}
+
 1;
 
 __END__
@@ -375,6 +536,11 @@ Data passed to new must comply to the object's structure or new() will
 complain. Objects passed must be of the expected type, or new() will
 complain, too.
 
+The special key B<xmlattr> may be used to pass XML attributes. This key is
+chosen, because "xmlattr" cannot legally be used as XML name (it starts with
+"xml"). Passing a hash ref structure as value to "xmlattr" has the same
+effect as passing the same structure to a call to C<$obj->attr()>
+
 Examples:
 
  my $obj = MyClass->new({ MyName => $value });
@@ -395,6 +561,16 @@ Examples:
      MyThirdName => [ $object1, $object2 ],
  });
 
+my $obj = MyClass->new({
+     xmlattr => { name => 'foo' },
+     MyName => {
+         DeepName => $value,
+     },
+     MySecondName => $value,
+ });
+
+In case your building on Class::Std, please note the following limitations:
+
 The new() method from Class::Std will be overridden, so you should not rely
 on it's behaviour.
 
@@ -420,16 +596,57 @@ This means you may set element properties by passing
 Examples are similar to the examples provided for new() above.
 
 Note that you cannot delete a property by setting it to undef - this sets
-the property to a empty property object (with vaue undef).
+the property to an empty property object (with value undef).
 
-To delete a property, say
+To delete a property, say:
 
  $obj->set_FOO();
 
+=head2 attr
+
+Returns / sets the attribute object associated with the object. XML Attributes
+are modeled as attribute objects - their classes are usually private (i.e.
+part of the associated class' file, not in a separate file named after the
+attribute class).
+
+Note that attribute support is still experimental.
+
+=head2 as_bool
+
+Returns the boolean value of the complexType (always true).
+
 =head2 as_hash_ref
 
 Returns a hash ref representation of the complexType object
 
+Attributes are included under the special key "xmlattr" (if any).
+
+The inclusion of attributes can be suppressed by calling
+
+ $obj->as_has_ref(1);
+
+or even globally by setting
+
+ $SOAP::WSDL::XSD::Typelib::ComplexType::AS_HASH_REF_WITHOUT_ATTRIBUTES = 1;
+
+Note that using the $AS_HASH_REF_WITHOUT_ATTRIBUTES global variable is
+strongly discouraged. Use of this variable is deprecated and will be removed
+as of version 2.1
+
+as_hash_ref can be used for deep cloning. The following statement creates
+a deep clone of a SOAP::WSDL::ComplexType-based object
+
+ my $clone = ref($obj)->new($obj->as_hash_ref());
+
+=head2 serialize_attr
+
+Serialize a complexType's attributes
+
+=head2 serialize
+
+Serialize a ComplexType object to XML. Exported via symbol table into derived
+classes.
+
 =head1 Bugs and limitations
 
 =over
@@ -469,10 +686,10 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 564 $
+ $Rev: 850 $
  $LastChangedBy: kutterma $
- $Id: ComplexType.pm 564 2008-02-23 13:31:39Z kutterma $
- $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/XSD/Typelib/ComplexType.pm $
+ $Id: ComplexType.pm 850 2009-05-15 22:31:44Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/branches/Typemap/lib/SOAP/WSDL/XSD/Typelib/ComplexType.pm $
 
 =cut
 
