@@ -1,9 +1,8 @@
-#!/usr/bin/perl
 package SOAP::WSDL::XSD::Typelib::Element;
+use strict; use warnings;
 use Class::Std::Fast::Storable constructor => 'none';
-use strict;
 
-our $VERSION=q{2.00_29};
+use version; our $VERSION = qv('2.00.99_1');
 
 my %NAME;
 my %NILLABLE;
@@ -25,14 +24,17 @@ BLOCK: {
         _maxOccurs => \%MAX_OCCURS,
     );
 
+    # create getters / setters for all elements' class data
     no strict qw(refs);
     while (my ($name, $value) = each %method_lookup ) {
         *{ "__set$name" } = sub {
-            my $class = ref $_[0] || $_[0] or die "Cannot call __set$name without parameter";
+            @_ or die "Cannot call __set$name without parameter";
+            my $class = ref $_[0] || $_[0];
             $value->{ $class } = $_[1];
         };
         *{ "__get$name" } = sub {
-            my $class = ref $_[0] || $_[0] or die "Cannot call __get$name as function";
+            @_ or die "Cannot call __set$name as function";
+            my $class = ref $_[0] || $_[0];
             return $value->{ $class };
         };
     }
@@ -51,9 +53,17 @@ sub start_tag {
         push @attr_from, q{ xsi:nil="true"};
         $ending = '/>';
     }
+
+    # add xmlns if requested
     if (delete $_[1]->{qualified}) {
         push @attr_from, q{ xmlns="} . $_[0]->get_xmlns() . q{"};
     }
+
+    # add xsi:type if requested
+    if (delete $_[1]->{derived}) {
+        push @attr_from, q{ xsi:type="} . $_[0]->get_xmltype() . q{"};
+    }
+
     push @attr_from, $_[0]->serialize_attr();
 
     # do we need to check for name ? Element ref="" should have it's own
@@ -175,10 +185,10 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 564 $
+ $Rev: 841 $
  $LastChangedBy: kutterma $
- $Id: Element.pm 564 2008-02-23 13:31:39Z kutterma $
- $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/XSD/Typelib/Element.pm $
+ $Id: Element.pm 841 2009-03-09 20:17:36Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/branches/Typemap/lib/SOAP/WSDL/XSD/Typelib/Element.pm $
 
 =cut
 
